import os
script_directory = os.path.dirname(os.path.abspath(__file__))

def set_path(path):
    try:
        with open(script_directory +'/default.txt','w') as file:
            file.write(path)
            print_success("default path changed to:")
            print(path)
    except Exception as e:
        print_error(e)
        


def print_help():
    print(" Forsee Beta:")  
    print(" Author Nikos Tzeka\n")

    print(" Forsee is a program created by Itec-audio and is used to generate a compile database\n specifically from CrossCore Embedded Studio\n")
    print(" In order for the program to work you need to get into CCES project propertied\n and make sure that the run commad is \'make -nw\' instead of \'make\'")
    print(" \n--------------------------------USAGE--------------------------------------\n")
    print(" If the DCT console logs in the default directory, then you only need to type your project name")
    print(" Otherwise you can change this directory with the --default option \n or give as input the whole path to you build.log file")
    print("\n\n")
    print("         OPTIONS")
    print("         ________")
    print("         -h   --help             prints this menu")
    print("         --default=path          sets the default searching directory")
    print("         --default               prints the current default path")
    print("         projectname             exports the compile commands in your projects directory")
    print("                                     e.g     c4 projectname1 projectname2 C:/absolute/path/to/the/build.log")
    print("\n\n")
    print(" \n!! Please Note that for now you can you only one type of argument at a time")
    print(" Thats all for now :)")
    print(" !!!!! VERY IMPORTANT !!!!!!!!")
    print(" o valatis einai omofoilofilos")
    exit()


def print_error(error):
    print("\033[31mFAIL:\033[0m")
    print("     error:" + error)

def print_success(msg):
    print("\033[32mSUCCESS:\033[0m")
    print(msg)




import sys
from .forsee_functions import *
from sre_constants import FAILURE, SUCCESS
from .args_handler import *




def main():

    #cces_log_file = "C:/Users/Nikolaos/cces/2.12.0/.metadata/.plugins/org.eclipse.cdt.ui/testAnalyser_Core0.build.log"

    defaultPath = set_def_path()

    arguments = sys.argv[1:]

    projects = handle_arguments(arguments)

    for i in range(0,len(projects)):


        
        ##get the path from arguments
        print(projects[i])
        cces_log_file = get_project_path(projects[i],defaultPath)
        if(cces_log_file == FAILURE):
            print_error("Path not Found")
            exit(1)


        #file is too populated...here we filter only the lines we need(command and file)
        filtered_lines = filter_data(cces_log_file)


        directory = get_directory(cces_log_file)
        command = ""
        file = ""
        jsonformat = []

        #the flag idea is to basically write to the json every second command

        for line in filtered_lines:
            if "lkfn" in line:
                command = line[:-1]
            if "Finished" in line:
                file = line.split(':')  #the line in the file is in this format  Funished build: ../path/to/the/thing/you.want"\n
                file = file[1]          #now we only keep the second part
                file = file[1:-2]       #and remove the first char (empty space) and the 2 last (\n and ')

                #organise the outputs so they are ready to be dumbed into the json
                jsonformat.append({
                    'directory' : directory,
                    'command': command,
                    'file': file
                })

        #dump data to json file
        output_file_path = directory + '/compile_commands.json'
        if(create_compiledb(output_file_path,jsonformat) == SUCCESS):
            print_success("You can find you compile_commands.json at:")
            print("         "+directory)
        else:
            print_error()

if __name__ == "__main__":

    main()





import json
import os
from sre_constants import FAILURE, SUCCESS
from .args_handler import print_error,print_help,print_success,set_path


#comment that in case we mess up and still need to go here
#defaultPath = "C:/Users/Nikolaos/cces/2.12.0/.metadata/.plugins/org.eclipse.cdt.ui/"

script_directory = os.path.dirname(os.path.abspath(__file__))


def set_def_path():
    try:
        with open(script_directory + '/default.txt','r') as file:
            somepaths = file.readlines()
            for line in  somepaths:
                return line.strip()
    except FileNotFoundError as e:
        with open(script_directory +'/default.txt','w') as file:
            relative_path = 'cces/2.12.0/.metadata/.plugins/org.eclipse.cdt.ui/'

            # Expand the user's home directory and join it with the relative path
            full_path = os.path.expanduser(os.path.join('~', relative_path))
            file.write(full_path)
            return full_path
            

def handle_arguments(arguments):
    if(len(arguments) == 0 ):
        print_error("No options presented")
        exit(0)
    if("-h" in arguments or "--help" in arguments):
        print_help()
        exit(0)
    
    for arg in arguments:
        if "--default" in arg:

            path = arg.split('=')
            if(len(path) > 1):
                set_path(path[1])
                exit(0)
            else: 
                print(set_def_path())
    else:
        return arguments


def create_compiledb(output_file_path,jsonformat):
    try:
        with open(output_file_path, 'w') as json_file:
            json.dump(jsonformat, json_file, indent=2)
            return SUCCESS
    except Exception as e:
        print_error("Could not generate the json file")


def get_project_path(project_name,defaultPath):
    if(project_name[0] == 'C'):
        if os.path.exists(project_name):
            return project_name
        return FAILURE
    else:
        for root,dirs,files in os.walk(defaultPath):
            for file in files:
                if project_name in file:
                    path = os.path.join(root,file)
                    print(path)
                    if os.path.exists(path):
                        return path
                    print(path)
    return FAILURE
                
def filter_data(cces_log_file):
    #clean the data
    strings_to_keep = ["lkfn","Finished building"]

    # Open the input file in read mode
    with open(cces_log_file, 'r') as infile:
        # Read all lines from the file      
        lines = infile.readlines()

    # Filter lines that contain the specific string
    return [line for line in lines 
            if (strings_to_keep[0] in line or
                strings_to_keep[1] in line
                ) ]

def get_directory(cces_log_file):
    with open(cces_log_file, 'r') as infile:
        for line in infile:
                if "entering directory" in line.lower():
                    path = line.split('\'')
                    return path[1]
                



from setuptools import setup,find_packages

setup(
    name='forsee',
    version='0.1.1',
    author='Nikos Tzekas',
    author_email='nt@itec-audio.com',
    description='Exports a compile_commands.json from a Crosscore Project',
    packages=find_packages(),
    install_requires=[
        # List your dependencies here
    ],
    entry_points={
        'console_scripts': [
            'c4=forsee.forsee:main',  
        ],
    },
)